@@ -107,8 +107,6 @@ class Perfil(core.models.Log):
     pontofuncao = models.ManyToManyField('sistema.PontoFuncao', through='sistema.PerfilPontoFuncao', through_fields=('perfil', 'pontofuncao'))
     perfil_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)
 
-    grupo = models.ManyToManyField('usr.Grupo', through='sistema.PerfilGrupo', through_fields=('perfil', 'grupo'))
-
     class Meta(core.models.Log.Meta):
         abstract = False
         db_table = 'sistema_perfil'
@@ -145,7 +143,7 @@ class PerfilLogin(core.models.Log):
         db_table = 'sistema_perfillogin'
 
 
-class PerfilGrupo(core.models.Log):
+class PerfilUsr(core.models.Log):
     """
     :Nome da classe/função: PerfilGrupo
     :descrição: Classe de relação entre o perfil no sistema e grupo de usuário
@@ -153,11 +151,17 @@ class PerfilGrupo(core.models.Log):
     :Edições:
     """
     perfil = models.ForeignKey('sistema.Perfil', on_delete=models.DO_NOTHING, null=True)
-    grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)
-
     dat_ini = models.DateField(null=True)
     dat_fim = models.DateField(null=True)
 
+    usr_id = models.IntegerField(null=True)
+    usr_codigo = models.CharField(null=True, max_length=200)
+    usr_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
+    usr = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr', to_fields={
+        "codigo": "usr_codigo",
+        "tipo": "usr_tipo"
+    })
+
     class Meta(core.models.Log.Meta):
         abstract = False
-        db_table = 'sistema_perfilgrupo'
+        db_table = 'sistema_perfilusr'
