@@ -93,6 +93,10 @@ class GrupoUser(core.models.Log):
     """
     grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)
 
+    codigo = models.IntegerField(null=True)
+    dat_ini = models.DateField(null=True)
+    dat_fim = models.DateField(null=True)
+
     usr_id = models.IntegerField(null=True)
     usr_codigo = models.CharField(null=True, max_length=200)
     usr_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
